@@ -1,5 +1,6 @@
 /* vim:set noet cinoptions= sw=4 ts=4:
 This file is part of the quoter project and distributed under the MIT license.
+SPDX-License-Identifier: MIT
 
 Copyright (c) Martin Väth <martin@mvath.de>
 
@@ -91,7 +92,7 @@ static char *a_para = "a";
 static char *empty = "";
 
 void version_and_exit() {
-	puts("quoter v3.0");
+	puts("quoter v4.1");
 	free_and_exit(EXIT_SUCCESS);
 }
 
@@ -106,7 +107,7 @@ void help_and_exit() {
 "-s or --short            output the shortest string as possible\n"
 "-S or --unshort          output readable and compatible length (default)\n"
 "-l or --long             output paranoically long/compatible\n"
-"-e or --empty-last       interpret trailing \0 as trailing empty string\n"
+"-e or --empty-last       interpret trailing \\0 as trailing empty string\n"
 "-c or --cut              omit trailing newline in output\n"
 "-V or --version          print version\n"
 "-h or --help             show this help text");
